"""
hub/
====

This subpackage handles all interactions with the Hugging Face Hub: fetching model metadata, 
safetensors headers via range requests, and anything else that involves grabbing data from remote.
"""